mustache library

Classes

LambdaContext
Passed as an argument to a mustache lambda function. The methods on this object may only be called before the lambda function returns. If a method is called after it has returned an exception will be thrown.
MissingVariableContext
Context passed to MissingVariableCallback.
Template
A Template can be efficiently rendered multiple times with different values.

Typedefs

LambdaFunction = Object Function(LambdaContext context)
MissingVariableCallback = String? Function(String name, MissingVariableContext context)
Called when rendering encounters a missing variable.
PartialResolver = Template? Function(String)

Exceptions / Errors

TemplateException
TemplateException is used to obtain the line and column numbers of the token which caused parse or render to fail.