MissingVariableContext class

Context passed to MissingVariableCallback.

This describes the missing variable occurrence currently being rendered.

Constructors

MissingVariableContext({required String? templateName, required String source, required int offset, required bool htmlEscape})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
htmlEscape bool
Whether the replacement text will be HTML-escaped.
final
offset int
The character offset of the missing variable tag.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
The template source being rendered.
final
templateName String?
The name used to identify the template, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited